#[repr(C)]pub struct WalHeader {
pub magic: u32,
pub file_format: u32,
pub page_size: u32,
pub checkpoint_seq: u32,
pub salt_1: u32,
pub salt_2: u32,
pub checksum_1: u32,
pub checksum_2: u32,
}Expand description
The Write-Ahead Log (WAL) header. The first 32 bytes of a WAL file comprise the WAL header. The WAL header is divided into the following fields stored in big-endian order.
Fields
magic: u32Magic number. 0x377f0682 or 0x377f0683 If the LSB is 0, checksums are native byte order, else checksums are serialized
file_format: u32WAL format version. Currently 3007000
page_size: u32Database page size in bytes. Power of two between 512 and 65536 inclusive
checkpoint_seq: u32Checkpoint sequence number. Increases with each checkpoint
salt_1: u32Random value used for the first salt in checksum calculations TODO: Incremented with each checkpoint
salt_2: u32Random value used for the second salt in checksum calculations. TODO: A different random value for each checkpoint
checksum_1: u32First checksum value in the wal-header
checksum_2: u32Second checksum value in the wal-header
Implementations