pub struct PreparedProgram {Show 17 fields
pub max_registers: usize,
pub insns: Vec<(Insn, usize)>,
pub cursor_ref: Vec<(Option<CursorKey>, CursorType)>,
pub comments: Vec<(u32, &'static str)>,
pub parameters: Parameters,
pub change_cnt_on: bool,
pub readonly: bool,
pub result_columns: Vec<ResultSetColumn>,
pub table_references: TableReferences,
pub sql: String,
pub needs_stmt_subtransactions: Arc<AtomicBool>,
pub trigger: Option<Arc<Trigger>>,
pub is_subprogram: bool,
pub resolve_type: ResolveType,
pub prepare_context: PrepareContext,
pub write_databases: BitSet,
pub read_databases: BitSet,
}Fields
max_registers: usizeinsns: Vec<(Insn, usize)>cursor_ref: Vec<(Option<CursorKey>, CursorType)>comments: Vec<(u32, &'static str)>parameters: Parameterschange_cnt_on: boolreadonly: boolFlag that detect if the sqlite statement will directly manipulate the database file.
mirrors: https://sqlite.org/c3ref/stmt_readonly.html.
result_columns: Vec<ResultSetColumn>table_references: TableReferencessql: Stringneeds_stmt_subtransactions: Arc<AtomicBool>Whether the statement needs to be wrapped in a statement subtransaction when run as part of an interactive (non-autocommit) transaction. See [crate::vdbe::builder::ProgramBuilder::is_multi_write] and [crate::vdbe::builder::ProgramBuilder::may_abort] for more details.
trigger: Option<Arc<Trigger>>If this Program is a trigger subprogram, a ref to the trigger is stored here.
is_subprogram: boolWhether this program is a subprogram (trigger or FK action) that runs within a parent statement.
resolve_type: ResolveTypeprepare_context: PrepareContextwrite_databases: BitSetSet of attached database indices that need write transactions.
read_databases: BitSetSet of attached database indices that need read transactions.
Implementations
Sourceimpl PreparedProgram
impl PreparedProgram
pub fn bind(self: Arc<Self>, connection: Arc<Connection>) -> Program
pub fn is_compatible_with(&self, connection: &Connection) -> bool
pub const fn is_readonly(&self) -> bool